variable "proxmox_apiuser" {
  type    = string
  default = "packer"
}

variable "proxmox_apitoken" {
  type    = string
  default = "changeme"
}

source "proxmox-iso" "rocky-10" {
  template_name            = "rocky-10"
  template_description     = "Rocky Linux 10.0, generated on ${timestamp()}"
  vm_id                    = "208"
  boot_wait                = "10s"
  boot_key_interval        = "200ms"
  boot_command             = ["e<wait1s>", "<down><down><down><left> inst.ks=http://{{ .HTTPIP }}:{{ .HTTPPort }}/rocky-server.ks", "<wait>", "<leftCtrlOn>x<leftCtrlOff>", "<wait3s>"]

  http_directory           = "http"
  http_port_max            = "8089"
  http_port_min            = "8080"

  os                       = "l26"
  cores                    = "2"
  sockets                  = "1"
  cpu_type                 = "host"
  memory                   = "2048"
  scsi_controller          = "virtio-scsi-single"
  disks {
    disk_size              = "30G"
    storage_pool           = "templates"
    type                   = "scsi"
    format                 = "qcow2"
  }
  network_adapters {
    bridge                 = "vmbr0"
    model                  = "virtio"
  }

  proxmox_url              = "https://kamino.int.metaunix.net:8006/api2/json/"
  insecure_skip_tls_verify = true
  username                 = "${var.proxmox_apiuser}"
  password                 = "${var.proxmox_apitoken}"
  node                     = "kamino"
  pool                     = "Templates"

  boot_iso {
    type                   = "scsi"
    iso_url                = "https://download.rockylinux.org/pub/rocky/10/isos/x86_64/Rocky-10.0-x86_64-boot.iso"
    iso_checksum           = "sha256:2bb073606d8d83cbd3c0e25c5e6cd8e5c60c0e989e6e84f0c415c05e163640d3"
    iso_download_pve       = true
    iso_storage_pool       = "iso"
    unmount                = true
  }

  ssh_username             = "xadmin"
  ssh_password             = "packer"
  ssh_timeout              = "20m"
}

build {
  sources = ["source.proxmox-iso.rocky-10"]

  provisioner "shell" {
    script = "scripts/rhel-install.sh"
  }

  provisioner "file" {
    source      = "scripts/initial-setup.sh"
    destination = "/home/xadmin/initial-setup.sh"
  }
}
